#!/bin/ksh
# Re-index any folders containing an executable "build" script.

PATH=/usr/local/bin:/bin:/sbin:/usr/sbin:/usr/bin
export PATH
umask 022

tag=`basename $0`
CALLER=$tag    # used by called scripts
export CALLER

top="/search/estraier"
logfile="$top/BUILDLOG"

die () {
    echo "$@" >& 2
    exit 1
}

logmsg () {
    ( echo; echo "`date`: $@" ) >> $logfile
}

# Update the index for each group of files.
# Skip any group with a "stop" file.

cd $top || die "cannot cd to $top"
test -f $logfile && rm $logfile
cp /dev/null README

for topic in *
do
    if test -d "$topic" -a -x "$topic/build"
    then
        if test -f "$topic/stop"
        then
            logmsg skipping $topic
        else
            logmsg starting $topic
            ( cd $topic && ./build 2>&1 ) >> $logfile

            ( echo "`date`: $topic"
              test -d $topic/srch && estcmd inform $topic/srch
              echo )                      >> README
        fi
    fi
done

logmsg DONE

# Clean up and link the logfile.

sedscr='
/passed .old document./d
/: passed$/d
/filling the key cache/d
/cleaning dispensable/d
s/^estcmd: INFO:/  estcmd: INFO:/
'

sed -e "$sedscr" $logfile > $logfile.n && mv $logfile.n $logfile

dest=`date "+OLD/%Y/%m%d"`
ln $logfile $top/$dest || die "ln $logfile $top/$dest failed"
exit 0
